# Community

Contributions to `ethology` are absolutely encouraged, whether to fix a bug,
develop a new feature, or improve the documentation.
To help you get started, we have prepared a statement on the project's [mission and scope](target-mission),
and a detailed [contributing guide](target-contributing).

:::{admonition} Get in touch
- [Chat with the team on Zulip](ethology-zulip:).
- [Open an issue](https://github.com/neuroinformatics-unit/ethology/issues) to report a bug or request a new feature.
:::


```{toctree}
:maxdepth: 2
:hidden:

mission-scope
related-projects
contributing
license
```
